<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.cc" line="+35"/>
        <source>About Transmission</source>
        <translation>Sobre o Transmission</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>A fast and easy BitTorrent client</source>
        <translation>Um cliente BitTorrent rápido e descomplicado</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Copyright (c) The Transmission Project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>C&amp;redits</source>
        <translation>Créditos</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Credits</source>
        <translation>Créditos</translation>
    </message>
</context>
<context>
    <name>Details</name>
    <message>
        <location filename="../details.cc" line="+153"/>
        <source>Torrent Properties</source>
        <translation>Propriedades do Torrent</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Information</source>
        <translation>Informação</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Peers</source>
        <translation>Fontes</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tracker</source>
        <translation>Rastreador</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Files</source>
        <translation>Arquivos</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location line="+176"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mixed</source>
        <translation>Misto</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+175"/>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Finished</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Paused</source>
        <translation>Pausado</translation>
    </message>
    <message>
        <source>%1 (%2%)</source>
        <translation type="obsolete">%1 (%2%)</translation>
    </message>
    <message>
        <source>%1 (+%2 corrupt)</source>
        <translation type="obsolete">%1 (+%2 corrompidos)</translation>
    </message>
    <message>
        <location line="+163"/>
        <source>Active now</source>
        <translation>Ativo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>%1 ago</source>
        <translation>%1 atrás</translation>
    </message>
    <message numerus="yes">
        <location line="+41"/>
        <source>%1 (%Ln pieces @ %2)</source>
        <translation>
            <numerusform>%1 (%Ln pedaço de %2)</numerusform>
            <numerusform>%1 (%Ln pedaços de %2)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+4"/>
        <source>%1 (%Ln pieces)</source>
        <translation>
            <numerusform>%1 (%Ln pedaço)</numerusform>
            <numerusform>%1 (%Ln pedaço)</numerusform>
        </translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Private to this tracker -- DHT and PEX disabled</source>
        <translation>Rastreador Privado -- DHT e PEX desativados</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Public torrent</source>
        <translation>Torrent Público</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Created by %1</source>
        <translation>Criado pelo %1</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Created on %1</source>
        <translation>Criado em</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Created by %1 on %2</source>
        <translation>Criado pelo %1 em %2</translation>
    </message>
    <message>
        <location line="+121"/>
        <location line="+21"/>
        <source>Encrypted connection</source>
        <translation>Conexão criptografada</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Optimistic unchoke</source>
        <translation>Desbloqueio otimista</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Downloading from this peer</source>
        <translation>Baixando desta fonte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>We would download from this peer if they would let us</source>
        <translation>Baixaríamos desta fonte se ela deixasse</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Uploading to peer</source>
        <translation>Enviando para a fonte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>We would upload to this peer if they asked</source>
        <translation>Enviaríamos para esta fonte se ela pedisse</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Peer has unchoked us, but we&apos;re not interested</source>
        <translation>A fonte nos desbloqueou, mas não estamos interessados</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>We unchoked this peer, but they&apos;re not interested</source>
        <translation>Desbloqueamos esta fonte, mas ela não está interessada</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Peer was discovered through DHT</source>
        <translation>A fonte foi descoberta por DHT</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Peer was discovered through Peer Exchange (PEX)</source>
        <translation>A fonte foi descoberta por Troca de Fontes (PEX)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Peer is an incoming connection</source>
        <translation>A fonte é uma conexão de entrada</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Activity</source>
        <translation>Atividade</translation>
    </message>
    <message>
        <source>Torrent size:</source>
        <translation type="obsolete">Tamanho:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Have:</source>
        <translation>Possui:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Availability:</source>
        <translation>Disponibilidade:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Downloaded:</source>
        <translation>Baixado:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Uploaded:</source>
        <translation>Enviado:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>State:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Running time:</source>
        <translation>Executando a:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Remaining time:</source>
        <translation>Tempo Restante:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Last activity:</source>
        <translation>Ultima Atividade:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Error:</source>
        <translation>Erro:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Location:</source>
        <translation>Local:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hash:</source>
        <translation>Hash:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Privacy:</source>
        <translation>Privacidade:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Origin:</source>
        <translation>Fonte:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Comment:</source>
        <translation>Comentário:</translation>
    </message>
    <message>
        <location line="+105"/>
        <location line="+12"/>
        <location line="+34"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location line="-34"/>
        <source>Tracker already exists.</source>
        <translation>O rastreador já existe</translation>
    </message>
    <message>
        <location line="-581"/>
        <source>%1 (100%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>%1 of %2 (%3%)</source>
        <translation type="unfinished">%1 de %2 (%3%)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 of %2 (%3%), %4 Unverified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>%1 (%2 corrupt)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+15"/>
        <source>%1 (Ratio: %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+181"/>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+217"/>
        <source>Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+102"/>
        <source>Add URL </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Add tracker announce URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <location line="+46"/>
        <source>Invalid URL &quot;%1&quot;</source>
        <translation>URL Inválida &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="-11"/>
        <source>Edit URL </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Edit tracker announce URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Speed</source>
        <translation>Velocidade</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Honor global &amp;limits</source>
        <translation>Respeitar limites globais</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Limit &amp;download speed (%1):</source>
        <translation>Limitar velocidade de download (%1):</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Limit &amp;upload speed (%1):</source>
        <translation>Limitar velocidade de upload (%1):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Torrent &amp;priority:</source>
        <translation>Prioridade do Torrent:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Seeding Limits</source>
        <translation>Limites de Envio</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+15"/>
        <source>Use Global Settings</source>
        <translation>Usar Configurações Globais</translation>
    </message>
    <message>
        <location line="-14"/>
        <source>Seed regardless of ratio</source>
        <translation>Semear independente da proporção</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding at ratio:</source>
        <translation>Parar de semear na proporção:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Ratio:</source>
        <translation>Proporção:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Seed regardless of activity</source>
        <translation>Semear independente de atividade</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding if idle for N minutes:</source>
        <translation>Parar de semear se ocioso por N minutos:</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Idle:</source>
        <translation>Ocioso:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer Connections</source>
        <translation>Conexões da Fonte</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Maximum peers:</source>
        <translation>Máximo de fontes:</translation>
    </message>
    <message>
        <location line="+75"/>
        <source>Show &amp;more details</source>
        <translation>Exibir mais detalhes</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show &amp;backup trackers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Up</source>
        <translation>Enviando</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Down</source>
        <translation>Baixando</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Address</source>
        <translation>Endereço</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Client</source>
        <translation>Cliente</translation>
    </message>
</context>
<context>
    <name>FileAdded</name>
    <message>
        <location filename="../options.cc" line="+68"/>
        <source>Error Adding Torrent</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileTreeItem</name>
    <message>
        <location filename="../file-tree.cc" line="+169"/>
        <source>Low</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mixed</source>
        <translation>Misto</translation>
    </message>
</context>
<context>
    <name>FileTreeModel</name>
    <message>
        <location line="+135"/>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Progress</source>
        <translation>Progresso</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Download</source>
        <translation>Baixando</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Priority</source>
        <translation>Prioridade</translation>
    </message>
</context>
<context>
    <name>FilterBar</name>
    <message>
        <location filename="../filterbar.cc" line="+223"/>
        <location line="+151"/>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-144"/>
        <source>Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Downloading</source>
        <translation type="unfinished">Baixando</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Seeding</source>
        <translation type="unfinished">Semeando</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Paused</source>
        <translation type="unfinished">Pausado</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Finished</source>
        <translation type="unfinished">Concluído</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Queued</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Verifying</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Error</source>
        <translation type="unfinished">Erro</translation>
    </message>
    <message>
        <location line="+147"/>
        <source>Show:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Formatter</name>
    <message>
        <location filename="../formatter.cc" line="+38"/>
        <source>B/s</source>
        <translation>B/s</translation>
    </message>
    <message>
        <location line="+12"/>
        <location line="+12"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location line="-23"/>
        <source>KiB/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>MiB/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>GiB/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>TiB/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <location line="+12"/>
        <source>KiB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location line="-11"/>
        <location line="+12"/>
        <source>MiB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location line="-11"/>
        <location line="+12"/>
        <source>GiB</source>
        <translation>GB</translation>
    </message>
    <message>
        <location line="-11"/>
        <location line="+12"/>
        <source>TiB</source>
        <translation>TB</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+12"/>
        <location line="+12"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message numerus="yes">
        <location line="+37"/>
        <source>%Ln day(s)</source>
        <translation>
            <numerusform>%Ln dia</numerusform>
            <numerusform>%Ln dias</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <source>%Ln hour(s)</source>
        <translation>
            <numerusform>%Ln hora</numerusform>
            <numerusform>%Ln horas</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuto</numerusform>
            <numerusform>%Ln minutos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <source>%Ln second(s)</source>
        <translation>
            <numerusform>%Ln segundo</numerusform>
            <numerusform>%Ln segundos</numerusform>
        </translation>
    </message>
    <message>
        <location line="+7"/>
        <location line="+7"/>
        <location line="+7"/>
        <source>%1, %2</source>
        <translation>%1, %2</translation>
    </message>
</context>
<context>
    <name>LicenseDialog</name>
    <message>
        <location filename="../license.cc" line="+22"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwin.ui" line="+14"/>
        <source>Transmission</source>
        <translation>Transmission</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>&amp;Torrent</source>
        <translation>Torrent</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>&amp;Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;View</source>
        <translation>Exibir</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>&amp;File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>toolBar</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Add File...</source>
        <translation type="obsolete">Adicionar Arquivo...</translation>
    </message>
    <message>
        <source>Add a torrent</source>
        <translation type="obsolete">Adiciona um torrent</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation type="obsolete">Ctrl+D</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>&amp;New...</source>
        <translation>Novo...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Create a new torrent</source>
        <translation>Cria um novo torrent</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Show torrent properties</source>
        <translation>Exibe as propriedades do torrent</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
    <message>
        <source>&amp;Open Folder</source>
        <translation type="obsolete">Abrir Pasta</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open the torrent&apos;s folder</source>
        <translation>Abre a pasta do torrent</translation>
    </message>
    <message>
        <location line="-30"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location line="-9"/>
        <source>&amp;Open...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open a torrent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Open Fold&amp;er</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Ctrl+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Start torrent</source>
        <translation>Inicia o torrent</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Ask Tracker for &amp;More Peers</source>
        <translation>Pedir Mais Fontes ao Rastreador</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ask tracker for more peers</source>
        <translation>Solicita mais fontes ao rastreador</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Pause torrent</source>
        <translation>Pausa o torrent</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Verify Local Data</source>
        <translation>Verificar Dados Locais</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Verify local data</source>
        <translation>Verifica os dados já baixados</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+V</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent</source>
        <translation>Apaga o torrent da lista</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Delete Files and Remove</source>
        <translation>Remover e Excluir Arquivos</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent and delete its files</source>
        <translation>Apaga o torrent da lista e exclui os arquivos associados</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Shift+Del</source>
        <translation>Shift+Del</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Start All</source>
        <translation>Iniciar Todos</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause All</source>
        <translation>Pausar Todos</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Select All</source>
        <translation>Selecionar Todos</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Deselect All</source>
        <translation>Selecionar Nenhum</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Preferences</source>
        <translation>Preferências</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Compact View</source>
        <translation>Modo Compacto</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+3"/>
        <source>Compact View</source>
        <translation>Modo Compacto</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Alt+C</source>
        <oldsource>Alt+M</oldsource>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Toolbar</source>
        <translation>Barra de Ferramentas</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Filterbar</source>
        <translation>Barra de Filtros</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statusbar</source>
        <translation>Barra de Estado</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Activity</source>
        <translation>Ordenar por Atividade</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by A&amp;ge</source>
        <translation>Ordenar por Idade</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Time &amp;Left</source>
        <translation>Ordenar por Tempo Restante</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Name</source>
        <translation>Ordenar por Nome</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Progress</source>
        <translation>Ordenar por Progresso</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Rati&amp;o</source>
        <translation>Ordenar por Proporção</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Si&amp;ze</source>
        <translation>Ordenar por Tamanho</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Stat&amp;e</source>
        <translation>Ordenar por Estado</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by T&amp;racker</source>
        <translation>Ordenar por Rastreador</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Message &amp;Log</source>
        <translation>Registro de Mensagens</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statistics</source>
        <translation>Estatísticas</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Contents</source>
        <translation>Conteúdo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Re&amp;verse Sort Order</source>
        <translation>Inverter Ordem</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Files</source>
        <translation>Arquivos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Tracker</source>
        <translation>Rastreador</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Ratio</source>
        <translation>Proporção Total</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Ratio</source>
        <translation>Proporção da Sessão</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Transfer</source>
        <translation>Transferẽncia Total</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Transfer</source>
        <translation>Transferência da Sessão</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Main Window</source>
        <translation>Janela Principal</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tray &amp;Icon</source>
        <translation>Ícone da Bandeja</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Change Session...</source>
        <translation>Alterar Sessão...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Choose Session</source>
        <extracomment>Start a local session or connect to a running session</extracomment>
        <translation>Escolher Sessão</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Set &amp;Location...</source>
        <translation>Definir Local...</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Copy Magnet Link to Clipboard</source>
        <translation>Copiar Link Magnet</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Open &amp;URL...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+U</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add &amp;URL...</source>
        <translation type="obsolete">Adicionar URL...</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Donate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MakeDialog</name>
    <message>
        <location filename="../make-dialog.cc" line="+85"/>
        <source>Creating &quot;%1&quot;</source>
        <translation>Criando &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Created &quot;%1&quot;!</source>
        <translation>&quot;%1&quot; Criado!</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Error: invalid announce URL &quot;%1&quot;</source>
        <translation>Erro: URL de anúncio inválida &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Cancelled</source>
        <translation>Cancelado</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Error reading &quot;%1&quot;: %2</source>
        <translation>Erro na leitura de &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Error writing &quot;%1&quot;: %2</source>
        <translation>Erro na gravação de &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location line="+33"/>
        <location line="+194"/>
        <source>New Torrent</source>
        <translation>Novo Torrent</translation>
    </message>
    <message>
        <location line="-151"/>
        <source>Select File</source>
        <translation>Selecionar Arquivo</translation>
    </message>
    <message>
        <location line="+23"/>
        <location line="+23"/>
        <source>Select Folder</source>
        <translation>Selecionar Pasta</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>&lt;i&gt;No source selected&lt;i&gt;</source>
        <translation>&lt;i&gt;Nenhuma fonte selecionada&lt;i&gt;</translation>
    </message>
    <message numerus="yes">
        <location line="+2"/>
        <source>%Ln File(s)</source>
        <translation>
            <numerusform>%Ln Arquivo</numerusform>
            <numerusform>%Ln Arquivos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <source>%Ln Piece(s)</source>
        <translation>
            <numerusform>%Ln Pedaço</numerusform>
            <numerusform>%Ln Pedaços</numerusform>
        </translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 in %2; %3 @ %4</source>
        <translation>%1 em %2; %3 @ %4</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Files</source>
        <translation>Arquivos</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Sa&amp;ve to:</source>
        <translation>Salvar em:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Source F&amp;older:</source>
        <translation>Pasta Fonte:</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+14"/>
        <source>(None)</source>
        <translation>(Nenhuma)</translation>
    </message>
    <message>
        <location line="-5"/>
        <source>Source &amp;File:</source>
        <translation>Arquivo Fonte:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Trackers:</source>
        <translation>Rastreadores:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>To add a backup URL, add it on the line after the primary URL.
To add another primary URL, add it after a blank line.</source>
        <translation>Adicione uma URL reserva na linha após a primária.
Adicione outra URL primária depois de uma linha em branco.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Co&amp;mment</source>
        <translation>Comentário</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Private torrent</source>
        <translation>Torrent Privado</translation>
    </message>
</context>
<context>
    <name>MyApp</name>
    <message>
        <location filename="../app.cc" line="+223"/>
        <source>Transmission is a file-sharing program.  When you run a torrent, its data will be made available to others by means of upload.  You and you alone are fully responsible for exercising proper judgement and abiding by your local laws.</source>
        <translation>O Transmission é um programa de compartilhamento de arquivos que torna os dados de cada torrent executado disponíveis a outras pessoas por meio do upload. Você e apenas você é responsável por respeitar as leis locais do seu país.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>I &amp;Agree</source>
        <translation>Aceito</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Torrent Added</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Options</name>
    <message>
        <source>Add Torrent</source>
        <translation type="obsolete">Adicionar Torrent</translation>
    </message>
    <message>
        <location filename="../options.cc" line="+22"/>
        <location line="+314"/>
        <source>Open Torrent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-303"/>
        <source>&amp;Torrent file:</source>
        <translation>Arquivo Torrent:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Destination folder:</source>
        <translation>Salvar na pasta:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Torrent &amp;priority:</source>
        <translation>Prioridade do torrent:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Verify Local Data</source>
        <translation>Verificar Dados Locais</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Start when added</source>
        <translation>Iniciar assim que adicionar</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Mo&amp;ve .torrent file to the trash</source>
        <translation>Mover arquivo .torrent para a lixeira</translation>
    </message>
    <message>
        <location line="+248"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>Arquivos Torrent (*.torrent);;Todos os Arquivos (*.*)</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Select Destination</source>
        <translation>Selecione o Destino</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <location filename="../prefs-dialog.cc" line="+186"/>
        <source>Use &amp;authentication</source>
        <translation>Usar autenticação</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Username:</source>
        <translation>Usuário:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Pass&amp;word:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <location line="-15"/>
        <source>Web Client</source>
        <translation>Interface Online</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Open web client</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Enable web client</source>
        <translation>Ativar interface online</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Listening &amp;port:</source>
        <translation>Escutar porta:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Only allow these IP a&amp;ddresses to connect:</source>
        <translation>Permitir conexão apenas dos endereços IP abaixo:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Addresses:</source>
        <translation>Endereços:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Speed Limits</source>
        <translation>Limites de Velocidade</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Limit &amp;download speed (%1):</source>
        <translation>Limitar velocidade de download (%1):</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Limit &amp;upload speed (%1):</source>
        <translation>Limitar velocidade de upload (%1):</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Temporary Speed Limits</source>
        <translation>Limites de Velocidade Temporários</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&lt;small&gt;Override normal speed limits manually or at scheduled times&lt;/small&gt;</source>
        <translation>&lt;small&gt;Sobrepõe os limites normais manualmente ou em tempos programados&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Limit u&amp;pload speed (%1):</source>
        <translation>Limitar velocidade de upload (%1):</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Scheduled times:</source>
        <translation>Agendar:</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>&amp;On days:</source>
        <translation>Nos dias</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Every Day</source>
        <translation>Todos</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekdays</source>
        <translation>Dias Úteis</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekends</source>
        <translation>Fins de Semana</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Monday</source>
        <translation>Segunda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tuesday</source>
        <translation>Terça</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Wednesday</source>
        <translation>Quarta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Thursday</source>
        <translation>Quinta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Friday</source>
        <translation>Sexta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Port is &lt;b&gt;open&lt;/b&gt;</source>
        <translation>A porta está &lt;b&gt;aberta&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Port is &lt;b&gt;closed&lt;/b&gt;</source>
        <translation>A porta está &lt;b&gt;fechada&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Testing...</source>
        <translation>Testando...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Incoming Peers</source>
        <translation>Conexões de Entrada</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+365"/>
        <source>Status unknown</source>
        <translation>Estado desconhecido</translation>
    </message>
    <message>
        <location line="-357"/>
        <source>&amp;Port for incoming connections:</source>
        <translation>Porta para conexões de entrada:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Use UPnP or NAT-PMP port &amp;forwarding from my router</source>
        <translation>Usar encaminhamento UPnP ou NAT-PMP no meu roteador</translation>
    </message>
    <message numerus="yes">
        <location line="+311"/>
        <source>&lt;i&gt;Blocklist contains %Ln rules&lt;/i&gt;</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location line="-312"/>
        <source>Pick a &amp;random port every time Transmission is started</source>
        <translation>Usar uma porta aleatória quando iniciar</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Limits</source>
        <translation>Limites</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Maximum peers per &amp;torrent:</source>
        <translation>Máximo de fontes por torrent:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Maximum peers &amp;overall:</source>
        <translation>Máximo de fontes ao todo:</translation>
    </message>
    <message numerus="yes">
        <location line="+28"/>
        <source>&lt;b&gt;Update succeeded!&lt;/b&gt;&lt;p&gt;Blocklist now has %Ln rules.</source>
        <translation>
            <numerusform>&lt;b&gt;Atualização concluída!&lt;/b&gt;&lt;p&gt;A lista de bloqueios tem agora %Ln regra.</numerusform>
            <numerusform>&lt;b&gt;Atualização concluída!&lt;/b&gt;&lt;p&gt;A lista de bloqueios tem agora %Ln regras.</numerusform>
        </translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&lt;b&gt;Update Blocklist&lt;/b&gt;&lt;p&gt;Getting new blocklist...</source>
        <translation>&lt;b&gt;Atualizando Lista de Bloqueios&lt;/b&gt;&lt;p&gt;Obtendo nova lista...</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Blocklist</source>
        <translation>Lista de Bloqueios</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Enable &amp;automatic updates</source>
        <translation>Atualizar automaticamente</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Allow encryption</source>
        <translation>Permitir</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prefer encryption</source>
        <translation>Preferir</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Require encryption</source>
        <translation>Exigir</translation>
    </message>
    <message>
        <location line="-5"/>
        <location line="+162"/>
        <source>Privacy</source>
        <translation>Privacidade</translation>
    </message>
    <message>
        <location line="-353"/>
        <source>Limit do&amp;wnload speed (%1):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+39"/>
        <location line="+302"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-300"/>
        <source>Show Transmission icon in the &amp;notification area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Show &amp;popup notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Te&amp;st Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Enable &amp;blocklist:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Encryption mode:</source>
        <translation>Criptografia:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use PE&amp;X to find more peers</source>
        <translation>Usar PEX para encontrar mais fontes</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>PEX is a tool for exchanging peer lists with the peers you&apos;re connected to.</source>
        <translation>O PEX é uma ferramenta que faz troca de fontes entre as fontes conectadas.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use &amp;DHT to find more peers</source>
        <translation>Usar DHT para encontrar mais fontes</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>DHT is a tool for finding peers without a tracker.</source>
        <translation>O DHT é uma ferramenta para localizar fontes sem um rastreador.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use &amp;Local Peer Discovery to find more peers</source>
        <translation>Usar Descoberta Local de Fontes para encontrar mais fontes</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>LPD is a tool for finding peers on your local network.</source>
        <translation>O LPD é uma ferramentas que encontra fontes na sua rede local.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Select &quot;Torrent Done&quot; Script</source>
        <translation>Selecione o Script</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Select Incomplete Directory</source>
        <translation>Pasta de Downloads Incompletos</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Select Watch Directory</source>
        <translation>Monitorar Pasta</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Select Destination</source>
        <translation>Seleciona o Destino</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Adding</source>
        <translation>Adicionando</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Automatically &amp;add torrents from:</source>
        <translation>Sempre adicionar torrents de:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Show &amp;options dialog</source>
        <translation>Exibir diálogo de opções</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Start when added</source>
        <translation>Iniciar assim que adicionar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mo&amp;ve .torrent file to the trash</source>
        <translation>Mover arquivo .torrent para a lixeira</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Downloading</source>
        <translation>Baixando</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Append &quot;.&amp;part&quot; to incomplete files&apos; names</source>
        <translation>Adicionar &quot;.part&quot; aos arquivos incompletos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Keep &amp;incomplete files in:</source>
        <translation>Manter arquivos incompletos em:</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Save to &amp;Location:</source>
        <translation>Salvar em:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Call scrip&amp;t when torrent is completed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Seeding Limits</source>
        <oldsource>Seeding</oldsource>
        <translation>Limites de Envio</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Stop seeding at &amp;ratio:</source>
        <translation>Parar de semear na proporção:</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Stop seeding if idle for &amp;N minutes:</source>
        <translation>Parar de semear se ocioso por N minutos:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Transmission Preferences</source>
        <translation>Preferências do Transmission</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Torrents</source>
        <translation>Torrents</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Speed</source>
        <translation>Velocidade</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Web</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Not supported by remote sessions</source>
        <translation>Não suportado por sessões remotas</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../app.cc" line="-145"/>
        <source>Invalid option</source>
        <translation>Opção inválida</translation>
    </message>
</context>
<context>
    <name>RelocateDialog</name>
    <message>
        <location filename="../relocate.cc" line="+51"/>
        <source>Select Location</source>
        <translation>Selecionar local</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Set Torrent Location</source>
        <translation>Definir Local do Torrent</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Set Location</source>
        <translation>Definir Local</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>New &amp;location:</source>
        <translation>Novo local:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Move from the current folder</source>
        <translation>Mover da pasta atual</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Local data is &amp;already there</source>
        <translation>Os dados locais já estão lá</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <location filename="../session.cc" line="+824"/>
        <source>Add Torrent</source>
        <translation>Adicionar Torrent</translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <location filename="../session-dialog.cc" line="+71"/>
        <source>Change Session</source>
        <translation>Alterar Sessão</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Source</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start &amp;Local Session</source>
        <translation>Iniciar Sessão Local</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Connect to &amp;Remote Session</source>
        <translation>Conectar numa Sessão Remota</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Host:</source>
        <translation>Servidor:</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Port:</source>
        <translation>Porta:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Authentication required</source>
        <translation>Requer autenticação</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Username:</source>
        <translation>Usuário:</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Pass&amp;word:</source>
        <translation>Senha:</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <location filename="../stats-dialog.cc" line="+35"/>
        <source>Statistics</source>
        <translation>Estatísticas</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Current Session</source>
        <translation>Sessão Atual</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+7"/>
        <source>Uploaded:</source>
        <translation>Enviado:</translation>
    </message>
    <message>
        <location line="-6"/>
        <location line="+7"/>
        <source>Downloaded:</source>
        <translation>Baixado:</translation>
    </message>
    <message>
        <location line="-6"/>
        <location line="+7"/>
        <source>Ratio:</source>
        <translation>Proporção:</translation>
    </message>
    <message>
        <location line="-6"/>
        <location line="+7"/>
        <source>Duration:</source>
        <translation>Duração:</translation>
    </message>
    <message>
        <location line="-5"/>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <location line="+53"/>
        <source>Started %n time(s)</source>
        <translation>
            <numerusform>Iniciado uma vez</numerusform>
            <numerusform>Iniciado %n vezes</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Torrent</name>
    <message>
        <location filename="../torrent.cc" line="+699"/>
        <source>Waiting to verify local data</source>
        <translation>Verificação de dados locais em espera</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Verifying local data</source>
        <translation>Verificando dados locais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Downloading</source>
        <translation>Baixando</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Seeding</source>
        <translation>Semeando</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Finished</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Paused</source>
        <translation>Pausado</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Tracker gave a warning: %1</source>
        <translation>O rastreador enviou um aviso: %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracker gave an error: %1</source>
        <translation>O rastreador enviou um erro: %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Error: %1</source>
        <translation>Erro: %1</translation>
    </message>
</context>
<context>
    <name>TorrentDelegate</name>
    <message>
        <location filename="../torrent-delegate.cc" line="+76"/>
        <source>Magnetized transfer - retrieving metadata (%1%)</source>
        <translation>Recebendo metadado da transferência Magnet (%1%)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 of %2 (%3%)</source>
        <translation>%1 de %2 (%3%)</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5 Goal: %6)</source>
        <translation>%1 de %2 (%3%), %4 enviados (Proporção: %5 Meta: %6)</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5)</source>
        <translation>%1 de %2 (%3%), %4 enviados (Proporção: %5)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>%1, uploaded %2 (Ratio: %3 Goal: %4)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+11"/>
        <source>%1, uploaded %2 (Ratio: %3)</source>
        <translation>%1, %2 enviados (Proporção: %3)</translation>
    </message>
    <message>
        <location line="+10"/>
        <location line="+102"/>
        <source> - </source>
        <translation> - </translation>
    </message>
    <message>
        <location line="-100"/>
        <source>%1 left</source>
        <translation>%1 restantes</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Remaining time unknown</source>
        <translation>Tempo restante desconhecido</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>%1 %2, %3 %4</source>
        <translation>%1 %2, %3 %4</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+2"/>
        <source>%1 %2</source>
        <oldsource>Up: %1</oldsource>
        <translation>%1 %2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Idle</source>
        <translation>Ocioso</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Verifying local data (%1% tested)</source>
        <translation>Verificando dados locais (%1% testado)</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Ratio: %1, </source>
        <translation>Proporção: %1, </translation>
    </message>
    <message numerus="yes">
        <location line="+31"/>
        <source>Downloading from %1 of %n connected peer(s)</source>
        <translation>
            <numerusform>Baixando de %1 fonte</numerusform>
            <numerusform>Baixando de %1 de %n fontes conectadasDownloading from %1 of %n connected peers</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>Downloading metadata from %n peer(s) (%1% done)</source>
        <translation>
            <numerusform>Baixando metadado de %n fontes (%1% concluído)</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+5"/>
        <source>Seeding to %1 of %n connected peer(s)</source>
        <translation>
            <numerusform>Semeando para %1 fonte</numerusform>
            <numerusform>Semeando para %1 de %n fontes conectadas</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TrMainWindow</name>
    <message>
        <location filename="../mainwin.cc" line="+451"/>
        <source>Limit Download Speed</source>
        <translation>Limitar Download</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+20"/>
        <source>Unlimited</source>
        <translation>Ilimitado</translation>
    </message>
    <message>
        <location line="-15"/>
        <location line="+20"/>
        <location line="+448"/>
        <location line="+8"/>
        <source>Limited at %1</source>
        <translation>Limitar em %1</translation>
    </message>
    <message>
        <location line="-464"/>
        <source>Limit Upload Speed</source>
        <translation>Limitar Upload</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Stop Seeding at Ratio</source>
        <translation>Parar de Semear na Proporção</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Seed Forever</source>
        <translation>Semear Eternamente</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+442"/>
        <source>Stop at Ratio (%1)</source>
        <translation>Parar na Proporção (%1)</translation>
    </message>
    <message>
        <location line="-318"/>
        <source> - %1:%2</source>
        <translation> - %1:%2</translation>
    </message>
    <message numerus="yes">
        <location line="+11"/>
        <source>%Ln Torrent(s)</source>
        <translation>
            <numerusform>%Ln Torrent</numerusform>
            <numerusform>%Ln Torrents</numerusform>
        </translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Idle</source>
        <translation type="unfinished">Ocioso</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Transmission
Up: %1
Down: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <location line="+16"/>
        <source>Ratio: %1</source>
        <translation>Proporção: %1</translation>
    </message>
    <message>
        <location line="-11"/>
        <location line="+6"/>
        <source>Down: %1, Up: %2</source>
        <translation>Baixado: %1 - Enviado: %2</translation>
    </message>
    <message>
        <location line="+315"/>
        <source>Click to disable Temporary Speed Limits
(%1 down, %2 up)</source>
        <translation>Desativar Limites Temporários de Velocidade
(baixar a %1 e semear a %2)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Click to enable Temporary Speed Limits
(%1 down, %2 up)</source>
        <translation>Ativar Limites Temporários de Velocidade
(baixar a %1 e enviar a %2)</translation>
    </message>
    <message>
        <source>Add Torrent</source>
        <translation type="obsolete">Adicionar Torrent</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>Arquivos Torrent (*.torrent);;Todos os Arquivos (*.*)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Show &amp;options dialog</source>
        <translation>Exibir diálogo de opções</translation>
    </message>
    <message>
        <source>Add URL or Magnet Link</source>
        <translation type="obsolete">Adicionar URL ou link Magnet</translation>
    </message>
    <message>
        <location line="-5"/>
        <source>Open Torrent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <location line="+1"/>
        <source>Open URL or Magnet Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+55"/>
        <source>Remove torrent?</source>
        <translation>Remover torrent?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Remove %1 torrents?</source>
        <translation>Remover %1 torrents?</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Delete this torrent&apos;s downloaded files?</source>
        <translation>Excluir este torrent e os arquivos baixados?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delete these %1 torrents&apos; downloaded files?</source>
        <translation>Excluir estes %1 torrents e arquivos baixados?</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Once removed, continuing the transfer will require the torrent file or magnet link.</source>
        <translation>Uma vez removido, para continuar a transferência será necessário o arquivo torrent ou o link Magnet.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Once removed, continuing the transfers will require the torrent files or magnet links.</source>
        <translation>Uma vez removidos, para continuar as transferências serão necessários os arquivos torrent ou os links Magnet.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>This torrent has not finished downloading.</source>
        <translation>A transferência deste torrent ainda não foi concluída.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>These torrents have not finished downloading.</source>
        <translation>As transferências destes torrents ainda não foram concluídas.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>This torrent is connected to peers.</source>
        <translation>Este torrent está conectado a fontes.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>These torrents are connected to peers.</source>
        <translation>Estes torrents estão conectados a fontes.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>One of these torrents is connected to peers.</source>
        <translation>Um destes torrents estão conectados a fontes.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents are connected to peers.</source>
        <translation>Alguns destes torrents estão conectados a fontes.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>One of these torrents has not finished downloading.</source>
        <translation>Um destes torrents ainda não foi concluído.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents have not finished downloading.</source>
        <translation>Alguns destes torrents ainda não foram concluídos.</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Transmission server is responding</source>
        <translation>O servidor do Transmission está respondendo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Last response from server was %1 ago</source>
        <translation>O servidor respondeu pela ultima vez à %1 atrás</translation>
    </message>
    <message numerus="yes">
        <location line="-580"/>
        <source>%L1 of %Ln Torrent(s)</source>
        <translation>
            <numerusform>%L1 of %Ln Torrent</numerusform>
            <numerusform>%L1 of %Ln Torrents</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TrackerDelegate</name>
    <message>
        <location filename="../tracker-delegate.cc" line="+161"/>
        <source>Got a list of %1%2 peers%3 %4 ago</source>
        <translation>Uma lista de %1%2 fontes%3 foi obtida %4 atrás</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Peer list request %1timed out%2 %3 ago; will retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Got an error %1&quot;%2&quot;%3 %4 ago</source>
        <translation type="unfinished">Erro obtido %1&apos;%2&apos;%3 %4 atrás {1&quot;%2&quot;%3 %4 ?}</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>No updates scheduled</source>
        <translation>Nenhuma atualização agendada</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Asking for more peers in %1</source>
        <translation>Pedindo mais fontes em %1</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued to ask for more peers</source>
        <translation>Pedido de mais fontes em espera</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Asking for more peers now... &lt;small&gt;%1&lt;/small&gt;</source>
        <translation>Pedindo mais fontes agora... &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Tracker had %1%2 seeders%3 and %4%5 leechers%6 %7 ago</source>
        <translation>O rastreador tinha %1%2 seeders%3 e %4%5 leechers%6 %7 atrás</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Got a scrape error %1&quot;%2&quot;%3 %4 ago</source>
        <translation type="unfinished">Erro no censo obtido %1&apos;%2&apos;%3 %4 atrás {1&quot;%2&quot;%3 %4 ?}</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Asking for peer counts in %1</source>
        <translation>Pedindo contagem de fontes em %1</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued to ask for peer counts</source>
        <translation>Pedido de contagem de peers em espera</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Asking for peer counts now... &lt;small&gt;%1&lt;/small&gt;</source>
        <translation>Pedindo contagem de peers agora... &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../utils.cc" line="+47"/>
        <source>Enter a location:</source>
        <translation>Digite um local</translation>
    </message>
</context>
</TS>
